src/hg/hgTracks/imageV2.h 1.10

1.10 2009/11/13 00:17:59 tdreszer
Changes to fix no leftLabel bug and changes to support separate button slice (needed for subtracks with separate imgTracks)
Index: src/hg/hgTracks/imageV2.h
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/hgTracks/imageV2.h,v
retrieving revision 1.9
retrieving revision 1.10
diff -b -B -U 4 -r1.9 -r1.10
--- src/hg/hgTracks/imageV2.h	11 Nov 2009 21:14:54 -0000	1.9
+++ src/hg/hgTracks/imageV2.h	13 Nov 2009 00:17:59 -0000	1.10
@@ -140,10 +140,11 @@
     {
     isUnknown=0,              // Invalid
     isData=1,                 // Data or track slice of an image
     isCenter=2,               // Top or centerLabel slice of an image
-    isSide=3,                 // Side or leftLabel slice of an image
-    isInvalid=4               // Invalid
+    isButton=3,               // Config button (by separating from side label, could have separate image which is swapped or colored by javascript)
+    isSide=4,                 // Side or leftLabel slice of an image
+    isInvalid=5               // Invalid
     };
 #define isMaxSliceTypes isInvalid
 struct imgSlice // IMAGEv2: the portion of an image that is displayable for one track
     {
@@ -207,11 +208,11 @@
 /* Updates an already existing image track */
 int imgTrackOrderCmp(const void *va, const void *vb);
 /* Compare to sort on label. */
 struct imgSlice *imgTrackSliceAdd(struct imgTrack *imgTrack,enum sliceType type, struct image *img,char *title,int width,int height,int offsetX,int offsetY);
 /* Adds slices to an image track.  Expected are types: isData, isSide and isCenter */
 struct imgSlice *imgTrackSliceGetByType(struct imgTrack *imgTrack,enum sliceType type);
 /* Gets a specific slice already added to an image track.  Expected are types: isData, isSide and isCenter */
 struct imgSlice *imgTrackSliceFindOrAdd(struct imgTrack *imgTrack,enum sliceType type, struct image *img,char *title,int width,int height,int offsetX,int offsetY);
 /* Find the slice or adds it */
 struct imgSlice *imgTrackSliceUpdateOrAdd(struct imgTrack *imgTrack,enum sliceType type, struct image *img,char *title,int width,int height,int offsetX,int offsetY);
 /* Updates the slice or adds it */
@@ -303,7 +304,12 @@
 #define imgBoxFree(a)
 #define IMG_ANYORDER  0
 #define IMG_FIXEDPOS  0
 #define IMG_ORDER_VAR "?"
+#define isData   0
+#define isCenter 2
+#define isSide   3
+#define isButton 4
+#define isMaxSliceTypes 1
 #endif//ndef IMAGEv2_UI
 
 #endif//ndef IMAGEV2_H
@@ -207,11 +208,11 @@
 /* Compare to sort on label. */
 struct imgSlice *imgTrackSliceAdd(struct imgTrack *imgTrack,enum sliceType type, struct image *img,char *title,int width,int height,int offsetX,int offsetY);
-/* Adds slices to an image track.  Expected are types: isData, isSide and isCenter */
+/* Adds slices to an image track.  Expected are types: isData, isButton, isSide and isCenter */
 struct imgSlice *imgTrackSliceGetByType(struct imgTrack *imgTrack,enum sliceType type);
@@ -207,11 +208,11 @@
 struct imgSlice *imgTrackSliceGetByType(struct imgTrack *imgTrack,enum sliceType type);
-/* Gets a specific slice already added to an image track.  Expected are types: isData, isSide and isCenter */
+/* Gets a specific slice already added to an image track.  Expected are types: isData, isButton, isSide and isCenter */
 struct imgSlice *imgTrackSliceFindOrAdd(struct imgTrack *imgTrack,enum sliceType type, struct image *img,char *title,int width,int height,int offsetX,int offsetY);
 /* Find the slice or adds it */